FL.objects.Font.Font
====================

.. currentmodule:: FL.objects.Font

.. autoclass:: Font
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Font.DefineAxis
      ~Font.DeleteAxis
      ~Font.FindGlyph
      ~Font.GenerateFont
      ~Font.GenerateGlyph
      ~Font.GenerateInstance
      ~Font.GenerateNames
      ~Font.GenerateUnicode
      ~Font.GetClassLeft
      ~Font.GetClassMetricsFlags
      ~Font.GetClassRight
      ~Font.MakeKernFeature
      ~Font.MergeFonts
      ~Font.New
      ~Font.Open
      ~Font.OpenAFM
      ~Font.Reencode
      ~Font.Save
      ~Font.SaveAFM
      ~Font.SetClassFlags
      ~Font.__init__
      ~Font.fake_binary_from_path
      ~Font.fake_binary_get
      ~Font.fake_bounding_rect
      ~Font.fake_deselect_all
      ~Font.fake_get_afm
      ~Font.fake_get_afm_kerning
      ~Font.fake_get_inf
      ~Font.fake_save_afm_expanded
      ~Font.fake_select
      ~Font.fake_set_class_flags
      ~Font.fake_set_features
      ~Font.fake_sort_glyphs
      ~Font.fake_sort_kerning
      ~Font.fake_update
      ~Font.has_key
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Font.apple_name
      ~Font.ascender
      ~Font.blue_fuzz
      ~Font.blue_scale
      ~Font.blue_shift
      ~Font.blue_values_num
      ~Font.blue_values
      ~Font.cap_height
      ~Font.codepages
      ~Font.copyright
      ~Font.customdata
      ~Font.default_character
      ~Font.default_width
      ~Font.descender
      ~Font.designer_url
      ~Font.designer
      ~Font.family_blues_num
      ~Font.family_blues
      ~Font.family_name
      ~Font.family_other_blues_num
      ~Font.family_other_blues
      ~Font.fond_id
      ~Font.font_name
      ~Font.font_style
      ~Font.force_bold
      ~Font.full_name
      ~Font.hguides
      ~Font.is_fixed_pitch
      ~Font.italic_angle
      ~Font.mac_compatible
      ~Font.menu_name
      ~Font.modified
      ~Font.ms_charset
      ~Font.ms_id
      ~Font.note
      ~Font.notice
      ~Font.ot_classes
      ~Font.other_blues_num
      ~Font.other_blues
      ~Font.panose
      ~Font.pcl_chars_set
      ~Font.pcl_id
      ~Font.pref_family_name
      ~Font.pref_style_name
      ~Font.slant_angle
      ~Font.source
      ~Font.stem_snap_h_num
      ~Font.stem_snap_h
      ~Font.stem_snap_v_num
      ~Font.stem_snap_v
      ~Font.style_name
      ~Font.trademark
      ~Font.tt_u_id
      ~Font.tt_version
      ~Font.ttinfo
      ~Font.underline_position
      ~Font.underline_thickness
      ~Font.unicoderanges
      ~Font.unique_id
      ~Font.upm
      ~Font.vendor_url
      ~Font.vendor
      ~Font.version_major
      ~Font.version_minor
      ~Font.version
      ~Font.vguides
      ~Font.vp_id
      ~Font.weight_code
      ~Font.weight_vector
      ~Font.weight
      ~Font.width
      ~Font.x_height
      ~Font.year
      ~Font.fake_vfb_object
      ~Font.axis
      ~Font.classes
      ~Font.encoding
      ~Font.fake_kerning
      ~Font.fake_sparse_json
      ~Font.features
      ~Font.file_name
      ~Font.fontnames
      ~Font.glyphs
      ~Font.truetypetables
      ~Font.xuid
      ~Font.xuid_num
   
   